@@ -111,6 +111,40 @@ import click
     default=None,
     is_flag=False,
 )
+@click.option(
+    "--cert",
+    "-c",
+    help="""
+    [Invenio v1.x ONLY] Full path to the certificate to use to authenticate.
+    Don't specify extension, only the file name. A '.key' and a '.pem' will be loaded.
+    Read documentation (CERN SSO authentication) to learn more on how to generate it.
+    """,
+    type=Text,
+    default=None,
+    is_flag=False,
+)
+@click.option(
+    "--invcookie",
+    "-ic",
+    help="""
+    [Invenio v1.x ONLY] Use custom INVENIOSESSION cookie value to authenticate.
+    Useful for local accounts.
+    """,
+    type=Text,
+    default=None,
+    is_flag=False,
+)
+@click.option(
+    "--skipssl",
+    "-ss",
+    help="""
+    [Invenio v1.x ONLY] Skip SSL authentication in HTTP requests.
+    Useful for misconfigured or deprecated instances.
+    """,
+    type=Text,
+    default=False,
+    is_flag=True,
+)
 def cli(
     recid,
     source,
@@ -124,6 +158,9 @@ def cli(
     very_verbose,
     bibdoc,
     bd_ssh_host,
+    cert,
+    invcookie,
+    skipssl
 ):
 
     # Select the desired log level (default is 2, warning)
@@ -148,6 +185,9 @@ def cli(
         alternate_uri,
         bibdoc,
         bd_ssh_host,
+        cert,
+        invcookie,
+        skipssl
     )
     print(f"Job result: {result}")
 
